%define _hardened_build 1
%define _legacy_common_support 1

Name:       distcc
Version:    3.4
Release:    %mkrel 8
Summary:    Distributed C/C++ compilation
Group:      Development/Tools
License:    GPLv2+
URL:        https://distcc.org/
Source0:    https://github.com/distcc/distcc/releases/download/v%{version}/distcc-%{version}.tar.gz
Source1:    hosts.sample
Source2:    distccd.service
#https://github.com/distcc/distcc/issues/110
Patch1:     path-masquarade.patch
Patch2:     fix-segfault.patch

BuildRequires: binutils-devel
BuildRequires: pkgconfig(popt)
BuildRequires: pkgconfig(gtk+-3.0)
BuildRequires: lzo-devel
BuildRequires: pkgconfig(python3)
BuildRequires: desktop-file-utils
BuildRequires: avahi-common-devel
BuildRequires: pkgconfig(avahi-client)
BuildRequires: pkgconfig(avahi-core)
Conflicts: %{name}-server < 3.3.3

%description
distcc is a program to distribute compilation of C or C++ code across
several machines on a network. distcc should always generate the same
results as a local compile, is simple to install and use, and is often
two or more times faster than a local compile.

%package    gnome
Summary:    Gnome frontend of distcc monitoring tool
Requires:   %{name} = %{version}-%{release}

%description gnome
This package contains the Gnome frontend of the distcc monitoring tool.

%package     server
Summary:    Server for distributed C/C++ compilation
Group:      Development/Tools
License:    GPLv2+

Requires: %{name} = %{version}-%{release}
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

%description server
This package contains the compilation server needed to use %{name}.


%prep
%autosetup -p1

%build
./autogen.sh
#https://githubhot.com/repo/distcc/distcc/issues/454
export CFLAGS="%{build_cflags} -DPY_SSIZE_T_CLEAN"
%configure \
	--disable-Werror \
	--without-gnome \
	--with-gtk
%make_build


%install
%make_install

# Install sample hosts file
install -Dm 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}/hosts

# Install sample distccd config file
install -Dm 0644 contrib/redhat/sysconfig %{buildroot}%{_sysconfdir}/sysconfig/distccd

# Install distcdd unit file
mkdir -p %{buildroot}%{_unitdir}
install -Dm 0755 %{SOURCE2} %{buildroot}%{_unitdir}/distccd.service

# Install distcc dirs
mkdir -p $RPM_BUILD_ROOT/usr/lib/distcc
mkdir -p $RPM_BUILD_ROOT/usr/lib/gcc-cross
if [ ! -d $RPM_BUILD_ROOT/usr/lib64 ]; then
  mkdir -p $RPM_BUILD_ROOT/usr/lib64	
fi
ln -s /usr/lib/distcc $RPM_BUILD_ROOT/usr/lib64/distcc

%post server
#[ $1 -lt 2 ] && /sbin/chkconfig --add distccd ||:
if [ $1 -eq 1 ] ; then
    # Initial installation
    /usr/bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi

%post
%{_sbindir}/update-distcc-symlinks

%preun server
#[ $1 -eq 0 ] && /sbin/chkconfig --del distccd ||:
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    /usr/bin/systemctl --no-reload disable distccd.service > /dev/null 2>&1 || :
    /usr/bin/systemctl stop distccd.service > /dev/null 2>&1 || :
fi

%postun server
/usr/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    # Package upgrade, not uninstall
    /usr/bin/systemctl try-restart distccd.service >/dev/null 2>&1 || :
fi

%files
%doc %{_datadir}/doc/%{name}
%{_bindir}/distcc
%{_bindir}/distccmon-text
%{_bindir}/lsdistcc
%{_bindir}/pump
%{_mandir}/man1/distcc.*
%{_mandir}/man1/distccmon-text*
%{_mandir}/man1/lsdistcc.*
%{_mandir}/man1/include_server*
%{_mandir}/man1/pump*
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/hosts
%{python3_sitearch}/include_server*
%{_sbindir}/update-distcc-symlinks
%dir /usr/lib/distcc
/usr/lib64/distcc
%dir /usr/lib/gcc-cross

%files gnome
%{_bindir}/distccmon-gnome
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/distccmon-gnome.png

%files server
%doc COPYING README
%{_bindir}/distccd
%{_unitdir}/*
%{_sysconfdir}/default/distcc
%{_sysconfdir}/distcc/*allow*
%{_mandir}/man1/distccd*
%config(noreplace) %{_sysconfdir}/sysconfig/distccd


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 3.4-8.mga10
+ Revision: 2243045
- Mageia 10 Mass Rebuild

* Wed Mar 05 2025 daviddavid <daviddavid> 3.4-7.mga10
+ Revision: 2160952
- rebuild for python 3.13

* Fri Aug 09 2024 joequant <joequant> 3.4-6.mga10
+ Revision: 2084418
- add patch to fix segfault

* Tue Jul 16 2024 pterjan <pterjan> 3.4-5.mga10
+ Revision: 2081760
- Drop unused BuildRequires on libgnomeui-2.0

* Sun Dec 04 2022 wally <wally> 3.4-4.mga10
+ Revision: 1916357
- properly set CFLAGS during the build to not override our clags

* Tue Apr 19 2022 joequant <joequant> 3.4-4.mga9
+ Revision: 1851799
- fix system error due to python 3.10

* Wed Apr 06 2022 umeabot <umeabot> 3.4-3.mga9
+ Revision: 1845871
- Mageia 9 Mass Rebuild

* Sun Feb 13 2022 joequant <joequant> 3.4-2.mga9
+ Revision: 1773927
- update to python 3.10

* Tue Oct 05 2021 joequant <joequant> 3.4-1.mga9
+ Revision: 1749555
- fix spec
- update to 3.4

* Sat Mar 20 2021 joequant <joequant> 3.3.5-2.mga9
+ Revision: 1705433
- update to python3.9

* Sat Feb 27 2021 joequant <joequant> 3.3.5-1.mga9
+ Revision: 1693103
- update to 3.3.5

* Wed Jul 22 2020 joequant <joequant> 3.3.3-6.mga8
+ Revision: 1608000
- remove deps from distcc

* Fri Jul 17 2020 joequant <joequant> 3.3.3-5.mga8
+ Revision: 1606869
- add patches

* Sun Jul 12 2020 joequant <joequant> 3.3.3-4.mga8
+ Revision: 1605456
- move items to distcc

* Sun Jul 12 2020 joequant <joequant> 3.3.3-3.mga8
+ Revision: 1605374
- add necessary directories for distcc

* Tue Feb 18 2020 umeabot <umeabot> 3.3.3-2.mga8
+ Revision: 1539222
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Dec 03 2019 wally <wally> 3.3.3-1.mga8
+ Revision: 1464162
- new version 3.3.3
- move pump and include_server to main pkg
- build without libgnomeui
- drop unused patches

* Mon Sep 09 2019 wally <wally> 3.3.2-3.mga8
+ Revision: 1439019
- rebuild for python3.8

* Wed Jan 09 2019 daviddavid <daviddavid> 3.3.2-2.mga7
+ Revision: 1353059
- rebuild for new Python 3.7

* Sat Dec 29 2018 shlomif <shlomif> 3.3.2-1.mga7
+ Revision: 1346563
- New version 3.3.2

* Sun Sep 23 2018 umeabot <umeabot> 3.3-2.mga7
+ Revision: 1297455
- Mageia 7 Mass Rebuild

* Tue Apr 03 2018 shlomif <shlomif> 3.3-1.mga7
+ Revision: 1215066
- New version 3.3

* Mon Feb 08 2016 umeabot <umeabot> 3.2rc1-11.mga6
+ Revision: 943260
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.2rc1-10.mga5
+ Revision: 748197
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.2rc1-9.mga5
+ Revision: 726140
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.2rc1-8.mga5
+ Revision: 678759
- Mageia 5 Mass Rebuild

* Wed Aug 20 2014 luigiwalser <luigiwalser> 3.2rc1-7.mga5
+ Revision: 666075
- add patch from fedora to fix CVE-2014-4607 in bundled minilzo

* Sat May 31 2014 pterjan <pterjan> 3.2rc1-6.mga5
+ Revision: 628161
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 3.2rc1-5.mga4
+ Revision: 542536
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 pterjan <pterjan> 3.2rc1-4.mga4
+ Revision: 497728
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Jan 11 2013 umeabot <umeabot> 3.2rc1-3.mga3
+ Revision: 348827
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 04 2013 kamil <kamil> 3.2rc1-2.mga3
+ Revision: 338794
- add P0: mga-fix-sv-coding-in-distccmon-gnome.desktop.patch
- remove triggerrun
- adapt for Mageia
- imported package distcc


* Thu Oct 25 2012 Jon Ciesla <limburgher@gmail.com> - 3.2rc1-1
- Latest upstream, BZ 870200.

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Apr 13 2012 Jon Ciesla <limburgher@gmail.com> - 3.1-6
- Add hardened build.

* Tue Jan 31 2012 Jon Ciesla <limburgher@gmail.com> - 3.1-5
- Migrate to systemd, BZ 770409.

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Nov 10 2011 Jon Ciesla <limb@jcomserv.net> - 3.1-3
- Rebuild for libpng 1.5.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Oct 07 2010 Jon Ciesla <limb@jcomserv.net> - 3.1-1
- New upstream, BZ 641032.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.18.3-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.18.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Feb 22 2008 Denis Leroy <denis@poolshark.org> - 2.18.3-4
- Added Avahi support patch from Lennart

* Tue Feb 19 2008 Denis Leroy <denis@poolshark.org> - 2.18.3-3
- LSB header for init script

* Mon Feb 18 2008 Denis Leroy <denis@poolshark.org> - 2.18.3-2
- Fixed Source0 URL, fixed init script

* Mon Feb  4 2008 Denis Leroy <denis@poolshark.org> - 2.18.3-1
- First version

